grib2io.tables.cf API documentation

# grib2io.tables.cf

View Source

      1# ----------------------------------------------------------------------------------------
      2# This table provides a mapping from the grib2io's shortName attr to CF standard name
      3# and cell method.
      4# ----------------------------------------------------------------------------------------
      5table_shortname_to_cf = {
      6    'ABSV': {'cf_standard_name': 'atmosphere_absolute_vorticity', 'cf_cell_methods': None},
      7    'DEN': {'cf_standard_name': 'air_density', 'cf_cell_methods': None},
      8    'DEPR': {'cf_standard_name': 'dew_point_depression', 'cf_cell_methods': None},
      9    'DPT': {'cf_standard_name': 'dew_point_temperature', 'cf_cell_methods': None},
     10    'DZDT': {'cf_standard_name': 'upward_air_velocity', 'cf_cell_methods': None},
     11    'EPOT': {'cf_standard_name': 'equivalent_potential_temperature', 'cf_cell_methods': None},
     12    'GP': {'cf_standard_name': 'geopotential', 'cf_cell_methods': None},
     13    'HGT': {'cf_standard_name': 'geopotential_height', 'cf_cell_methods': None},
     14    'DIST': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     15    'LAPR': {'cf_standard_name': 'air_temperature_lapse_rate', 'cf_cell_methods': None},
     16    'MIXR': {'cf_standard_name': 'humidity_mixing_ratio', 'cf_cell_methods': None},
     17    'POT': {'cf_standard_name': 'air_potential_temperature', 'cf_cell_methods': None},
     18    'PRES': {'cf_standard_name': 'air_pressure', 'cf_cell_methods': None},
     19    'PRMSL': {'cf_standard_name': 'air_pressure_at_mean_sea_level', 'cf_cell_methods': None},
     20    'PTEND': {'cf_standard_name': 'tendency_of_air_pressure', 'cf_cell_methods': None},
     21    'PVORT': {'cf_standard_name': 'atmosphere_potential_vorticity', 'cf_cell_methods': None},
     22    'RELV': {'cf_standard_name': 'atmosphere_relative_vorticity', 'cf_cell_methods': None},
     23    'RH': {'cf_standard_name': 'relative_humidity', 'cf_cell_methods': None},
     24    'SPFH': {'cf_standard_name': 'specific_humidity', 'cf_cell_methods': None},
     25    'STRM': {'cf_standard_name': 'atmosphere_streamfunction', 'cf_cell_methods': None},
     26    'TMAX': {'cf_standard_name': 'air_temperature', 'cf_cell_methods': 'time: maximum'},
     27    'TMIN': {'cf_standard_name': 'air_temperature', 'cf_cell_methods': 'time: minimum'},
     28    'MAXRH': {'cf_standard_name': 'relative_humidity', 'cf_cell_methods': 'time: maximum'},
     29    'MINRH': {'cf_standard_name': 'relative_humidity', 'cf_cell_methods': 'time: minimum'},
     30    'TMP': {'cf_standard_name': 'air_temperature', 'cf_cell_methods': None},
     31    'CAPE': {'cf_standard_name': 'atmosphere_convective_available_potential_energy', 'cf_cell_methods': None},
     32    'CEIL': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     33    'ICSEV': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     34    'ICPRB': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     35    'SIPD': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     36    'ELLINX': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     37    'TURB': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     38    'CLOUDBASE': {'cf_standard_name': 'cloud_base_altitude', 'cf_cell_methods': None},
     39    'DRYTPROB': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     40    'TSTM': {'cf_standard_name': 'thunderstorm_probability', 'cf_cell_methods': None},
     41    'TRWSPD': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     42    'TRWDIR': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     43    'VRATE': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     44    'RETOP': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     45    'MIXHT': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     46    'PWTHER': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     47    'MAXREF': {'cf_standard_name': 'equivalent_reflectivity_factor', 'cf_cell_methods': None},
     48    'SNOWLR': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     49    'SNOWLVL': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     50    'ASNOW': {'cf_standard_name': 'thickness_of_snowfall_amount', 'cf_cell_methods': None},
     51    'FICEAC': {'cf_standard_name': 'unknown', 'cf_cell_methods': None},
     52    'APTMP': {'cf_standard_name': 'apparent_air_temperature', 'cf_cell_methods': None},
     53    'UGRD': {'cf_standard_name': 'eastward_wind', 'cf_cell_methods': None},
     54    'VAPP': {'cf_standard_name': 'water_vapor_partial_pressure_in_air', 'cf_cell_methods': None},
     55    'VGRD': {'cf_standard_name': 'northward_wind', 'cf_cell_methods': None},
     56    'VPOT': {'cf_standard_name': 'atmosphere_velocity_potential', 'cf_cell_methods': None},
     57    'VTMP': {'cf_standard_name': 'virtual_temperature', 'cf_cell_methods': None},
     58    'VVEL': {'cf_standard_name': 'lagrangian_tendency_of_air_pressure', 'cf_cell_methods': None},
     59    'VUCSH': {'cf_standard_name': 'eastward_wind_shear', 'cf_cell_methods': None},
     60    'VVCSH': {'cf_standard_name': 'northward_wind_shear', 'cf_cell_methods': None},
     61    'WDIR': {'cf_standard_name': 'wind_from_direction', 'cf_cell_methods': None},
     62    'WIND': {'cf_standard_name': 'wind_speed', 'cf_cell_methods': None},
     63    'GUST': {'cf_standard_name': 'wind_speed_of_gust', 'cf_cell_methods': None},
     64    'WTMP': {'cf_standard_name': 'sea_water_temperature', 'cf_cell_methods': None},
     65    'ACPCP': {'cf_standard_name': 'lwe_thickness_of_convective_precipitation_amount', 'cf_cell_methods': 'time: sum'},
     66    'PTYPE': {'cf_standard_name': 'predominant_precipitation_type_at_surface', 'cf_cell_methods': None},
     67    'APCP': {'cf_standard_name': 'lwe_thickness_of_precipitation_amount', 'cf_cell_methods': 'time: sum'},
     68    'CICE': {'cf_standard_name': 'atmosphere_cloud_ice_content', 'cf_cell_methods': None},
     69    'CWAT': {'cf_standard_name': 'atmosphere_cloud_condensate_content', 'cf_cell_methods': None},
     70    'EVP': {'cf_standard_name': 'water_evaporation_flux', 'cf_cell_methods': 'time: mean'},
     71    'HCDC': {'cf_standard_name': 'high_type_cloud_area_fraction', 'cf_cell_methods': None},
     72    'LCDC': {'cf_standard_name': 'low_type_cloud_area_fraction', 'cf_cell_methods': None},
     73    'MCDC': {'cf_standard_name': 'medium_type_cloud_area_fraction', 'cf_cell_methods': None},
     74    'NCPCP': {'cf_standard_name': 'lwe_thickness_of_large_scale_precipitation_amount', 'cf_cell_methods': 'time: sum'},
     75    'PRATE': {'cf_standard_name': 'precipitation_flux', 'cf_cell_methods': None},
     76    'PWAT': {'cf_standard_name': 'atmosphere_water_vapor_content', 'cf_cell_methods': None},
     77    'SNOC': {'cf_standard_name': 'lwe_thickness_of_convective_snowfall_amount', 'cf_cell_methods': 'time: sum'},
     78    'SNOL': {'cf_standard_name': 'lwe_thickness_of_large_scale_snowfall_amount', 'cf_cell_methods': 'time: sum'},
     79    'TCDC': {'cf_standard_name': 'cloud_area_fraction', 'cf_cell_methods': None},
     80    'WEASD': {'cf_standard_name': 'lwe_thickness_of_surface_snow_amount', 'cf_cell_methods': 'time: sum'},
     81    'LAND': {'cf_standard_name': 'land_area_fraction', 'cf_cell_methods': None},
     82    'SFCR': {'cf_standard_name': 'surface_roughness_length', 'cf_cell_methods': None},
     83    'SNOD': {'cf_standard_name': 'surface_snow_thickness', 'cf_cell_methods': None},
     84    'SNOM': {'cf_standard_name': 'surface_snow_melt_flux', 'cf_cell_methods': 'time: mean'},
     85    'SOILM': {'cf_standard_name': 'soil_moisture_content', 'cf_cell_methods': None},
     86    'TSOIL': {'cf_standard_name': 'soil_temperature', 'cf_cell_methods': None},
     87    'VEG': {'cf_standard_name': 'vegetation_area_fraction', 'cf_cell_methods': None},
     88    'WATR': {'cf_standard_name': 'runoff_flux', 'cf_cell_methods': 'time: mean'},
     89    'ALBDO': {'cf_standard_name': 'surface_albedo', 'cf_cell_methods': None},
     90    'DLWRF': {'cf_standard_name': 'surface_downwelling_longwave_flux_in_air', 'cf_cell_methods': 'time: mean'},
     91    'DSWRF': {'cf_standard_name': 'surface_downwelling_shortwave_flux_in_air', 'cf_cell_methods': 'time: mean'},
     92    'GRAD': {'cf_standard_name': 'surface_downwelling_shortwave_flux_in_air', 'cf_cell_methods': 'time: mean'},
     93    'LHTFL': {'cf_standard_name': 'surface_upward_latent_heat_flux', 'cf_cell_methods': 'time: mean'},
     94    'NLWRS': {'cf_standard_name': 'surface_net_downward_longwave_flux', 'cf_cell_methods': 'time: mean'},
     95    'NLWRT': {'cf_standard_name': 'toa_net_downward_longwave_flux', 'cf_cell_methods': 'time: mean'},
     96    'NSWRS': {'cf_standard_name': 'surface_net_downward_shortwave_flux', 'cf_cell_methods': 'time: mean'},
     97    'NSWRT': {'cf_standard_name': 'toa_net_downward_shortwave_flux', 'cf_cell_methods': 'time: mean'},
     98    'SHTFL': {'cf_standard_name': 'surface_upward_sensible_heat_flux', 'cf_cell_methods': 'time: mean'},
     99    'ULWRF': {'cf_standard_name': 'surface_upwelling_longwave_flux_in_air', 'cf_cell_methods': 'time: mean'},
    100    'USWRF': {'cf_standard_name': 'surface_upwelling_shortwave_flux_in_air', 'cf_cell_methods': 'time: mean'},
    101    'DSLM': {'cf_standard_name': 'sea_surface_height_above_sea_level', 'cf_cell_methods': None},
    102    'HTSGW': {'cf_standard_name': 'sea_surface_wave_significant_height', 'cf_cell_methods': None},
    103    'ICEC': {'cf_standard_name': 'sea_ice_area_fraction', 'cf_cell_methods': None},
    104    'ICETK': {'cf_standard_name': 'sea_ice_thickness', 'cf_cell_methods': None},
    105    'SALTY': {'cf_standard_name': 'sea_water_salinity', 'cf_cell_methods': None},
    106    'SWELL': {'cf_standard_name': 'sea_surface_swell_wave_significant_height', 'cf_cell_methods': None},
    107    'SWDIR': {'cf_standard_name': 'sea_surface_swell_wave_from_direction', 'cf_cell_methods': None},
    108    'SWPER': {'cf_standard_name': 'sea_surface_swell_wave_period', 'cf_cell_methods': None},
    109    'UOGRD': {'cf_standard_name': 'eastward_sea_water_velocity', 'cf_cell_methods': None},
    110    'VOGRD': {'cf_standard_name': 'northward_sea_water_velocity', 'cf_cell_methods': None},
    111    'WTMP': {'cf_standard_name': 'sea_water_temperature', 'cf_cell_methods': None},
    112    'WVDIR': {'cf_standard_name': 'sea_surface_wind_wave_from_direction', 'cf_cell_methods': None},
    113    'WVHGT': {'cf_standard_name': 'sea_surface_wind_wave_significant_height', 'cf_cell_methods': None},
    114    'WVPER': {'cf_standard_name': 'sea_surface_wind_wave_period', 'cf_cell_methods': None},
    115    'TOZNE': {'cf_standard_name': 'atmosphere_mole_content_of_ozone', 'cf_cell_methods': None},
    116    'VIS': {'cf_standard_name': 'visibility_in_air', 'cf_cell_methods': None},
    117}
    118
    119# ----------------------------------------------------------------------------------------
    120# A dictionary to map GRIB2 Code Table 4.7 (Derived Forecast) to their equivalent
    121# CF Convention cell_methods.
    122# ----------------------------------------------------------------------------------------
    123table_4_7_cf = {
    124    0: {'cf_cell_methods': 'time: mean'},
    125    1: {'cf_cell_methods': 'time: mean (comment: weighted)'},
    126    2: {'cf_cell_methods': 'time: standard_deviation (comment: with respect to cluster mean)'},
    127    3: {'cf_cell_methods': 'time: standard_deviation (comment: normalized)'},
    128    4: {'cf_cell_methods': 'time: standard_deviation'},
    129    5: {'cf_cell_methods': None}, # No direct CF equivalent
    130    6: {'cf_cell_methods': 'time: mean (comment: of cluster members)'},
    131    7: {'cf_cell_methods': 'time: range (comment: interquartile)'},
    132    8: {'cf_cell_methods': 'time: minimum'},
    133    9: {'cf_cell_methods': 'time: maximum'},
    134    10: {'cf_cell_methods': 'time: variance'},
    135    192: {'cf_cell_methods': 'time: mode'},
    136    193: {'cf_cell_methods': None}, # No direct CF equivalent
    137    194: {'cf_cell_methods': 'time: median'},
    138    195: {'cf_cell_methods': None}, # No direct CF equivalent
    139    197: {'cf_cell_methods': None}, # No direct CF equivalent
    140    198: {'cf_cell_methods': None}, # Not a cell method
    141    199: {'cf_cell_methods': None}, # No direct CF equivalent
    142    200: {'cf_cell_methods': 'time: mean'},
    143    201: {'cf_cell_methods': None}, # No direct CF equivalent
    144    202: {'cf_cell_methods': None}, # No direct CF equivalent
    145    203: {'cf_cell_methods': None}, # No direct CF equivalent
    146    204: {'cf_cell_methods': None}, # No direct CF equivalent
    147    255: {'cf_cell_methods': None}, # Represents a missing value
    148}

table_shortname_to_cf = {'ABSV': {'cf_standard_name': 'atmosphere_absolute_vorticity', 'cf_cell_methods': None}, 'DEN': {'cf_standard_name': 'air_density', 'cf_cell_methods': None}, 'DEPR': {'cf_standard_name': 'dew_point_depression', 'cf_cell_methods': None}, 'DPT': {'cf_standard_name': 'dew_point_temperature', 'cf_cell_methods': None}, 'DZDT': {'cf_standard_name': 'upward_air_velocity', 'cf_cell_methods': None}, 'EPOT': {'cf_standard_name': 'equivalent_potential_temperature', 'cf_cell_methods': None}, 'GP': {'cf_standard_name': 'geopotential', 'cf_cell_methods': None}, 'HGT': {'cf_standard_name': 'geopotential_height', 'cf_cell_methods': None}, 'DIST': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'LAPR': {'cf_standard_name': 'air_temperature_lapse_rate', 'cf_cell_methods': None}, 'MIXR': {'cf_standard_name': 'humidity_mixing_ratio', 'cf_cell_methods': None}, 'POT': {'cf_standard_name': 'air_potential_temperature', 'cf_cell_methods': None}, 'PRES': {'cf_standard_name': 'air_pressure', 'cf_cell_methods': None}, 'PRMSL': {'cf_standard_name': 'air_pressure_at_mean_sea_level', 'cf_cell_methods': None}, 'PTEND': {'cf_standard_name': 'tendency_of_air_pressure', 'cf_cell_methods': None}, 'PVORT': {'cf_standard_name': 'atmosphere_potential_vorticity', 'cf_cell_methods': None}, 'RELV': {'cf_standard_name': 'atmosphere_relative_vorticity', 'cf_cell_methods': None}, 'RH': {'cf_standard_name': 'relative_humidity', 'cf_cell_methods': None}, 'SPFH': {'cf_standard_name': 'specific_humidity', 'cf_cell_methods': None}, 'STRM': {'cf_standard_name': 'atmosphere_streamfunction', 'cf_cell_methods': None}, 'TMAX': {'cf_standard_name': 'air_temperature', 'cf_cell_methods': 'time: maximum'}, 'TMIN': {'cf_standard_name': 'air_temperature', 'cf_cell_methods': 'time: minimum'}, 'MAXRH': {'cf_standard_name': 'relative_humidity', 'cf_cell_methods': 'time: maximum'}, 'MINRH': {'cf_standard_name': 'relative_humidity', 'cf_cell_methods': 'time: minimum'}, 'TMP': {'cf_standard_name': 'air_temperature', 'cf_cell_methods': None}, 'CAPE': {'cf_standard_name': 'atmosphere_convective_available_potential_energy', 'cf_cell_methods': None}, 'CEIL': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'ICSEV': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'ICPRB': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'SIPD': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'ELLINX': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'TURB': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'CLOUDBASE': {'cf_standard_name': 'cloud_base_altitude', 'cf_cell_methods': None}, 'DRYTPROB': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'TSTM': {'cf_standard_name': 'thunderstorm_probability', 'cf_cell_methods': None}, 'TRWSPD': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'TRWDIR': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'VRATE': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'RETOP': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'MIXHT': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'PWTHER': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'MAXREF': {'cf_standard_name': 'equivalent_reflectivity_factor', 'cf_cell_methods': None}, 'SNOWLR': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'SNOWLVL': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'ASNOW': {'cf_standard_name': 'thickness_of_snowfall_amount', 'cf_cell_methods': None}, 'FICEAC': {'cf_standard_name': 'unknown', 'cf_cell_methods': None}, 'APTMP': {'cf_standard_name': 'apparent_air_temperature', 'cf_cell_methods': None}, 'UGRD': {'cf_standard_name': 'eastward_wind', 'cf_cell_methods': None}, 'VAPP': {'cf_standard_name': 'water_vapor_partial_pressure_in_air', 'cf_cell_methods': None}, 'VGRD': {'cf_standard_name': 'northward_wind', 'cf_cell_methods': None}, 'VPOT': {'cf_standard_name': 'atmosphere_velocity_potential', 'cf_cell_methods': None}, 'VTMP': {'cf_standard_name': 'virtual_temperature', 'cf_cell_methods': None}, 'VVEL': {'cf_standard_name': 'lagrangian_tendency_of_air_pressure', 'cf_cell_methods': None}, 'VUCSH': {'cf_standard_name': 'eastward_wind_shear', 'cf_cell_methods': None}, 'VVCSH': {'cf_standard_name': 'northward_wind_shear', 'cf_cell_methods': None}, 'WDIR': {'cf_standard_name': 'wind_from_direction', 'cf_cell_methods': None}, 'WIND': {'cf_standard_name': 'wind_speed', 'cf_cell_methods': None}, 'GUST': {'cf_standard_name': 'wind_speed_of_gust', 'cf_cell_methods': None}, 'WTMP': {'cf_standard_name': 'sea_water_temperature', 'cf_cell_methods': None}, 'ACPCP': {'cf_standard_name': 'lwe_thickness_of_convective_precipitation_amount', 'cf_cell_methods': 'time: sum'}, 'PTYPE': {'cf_standard_name': 'predominant_precipitation_type_at_surface', 'cf_cell_methods': None}, 'APCP': {'cf_standard_name': 'lwe_thickness_of_precipitation_amount', 'cf_cell_methods': 'time: sum'}, 'CICE': {'cf_standard_name': 'atmosphere_cloud_ice_content', 'cf_cell_methods': None}, 'CWAT': {'cf_standard_name': 'atmosphere_cloud_condensate_content', 'cf_cell_methods': None}, 'EVP': {'cf_standard_name': 'water_evaporation_flux', 'cf_cell_methods': 'time: mean'}, 'HCDC': {'cf_standard_name': 'high_type_cloud_area_fraction', 'cf_cell_methods': None}, 'LCDC': {'cf_standard_name': 'low_type_cloud_area_fraction', 'cf_cell_methods': None}, 'MCDC': {'cf_standard_name': 'medium_type_cloud_area_fraction', 'cf_cell_methods': None}, 'NCPCP': {'cf_standard_name': 'lwe_thickness_of_large_scale_precipitation_amount', 'cf_cell_methods': 'time: sum'}, 'PRATE': {'cf_standard_name': 'precipitation_flux', 'cf_cell_methods': None}, 'PWAT': {'cf_standard_name': 'atmosphere_water_vapor_content', 'cf_cell_methods': None}, 'SNOC': {'cf_standard_name': 'lwe_thickness_of_convective_snowfall_amount', 'cf_cell_methods': 'time: sum'}, 'SNOL': {'cf_standard_name': 'lwe_thickness_of_large_scale_snowfall_amount', 'cf_cell_methods': 'time: sum'}, 'TCDC': {'cf_standard_name': 'cloud_area_fraction', 'cf_cell_methods': None}, 'WEASD': {'cf_standard_name': 'lwe_thickness_of_surface_snow_amount', 'cf_cell_methods': 'time: sum'}, 'LAND': {'cf_standard_name': 'land_area_fraction', 'cf_cell_methods': None}, 'SFCR': {'cf_standard_name': 'surface_roughness_length', 'cf_cell_methods': None}, 'SNOD': {'cf_standard_name': 'surface_snow_thickness', 'cf_cell_methods': None}, 'SNOM': {'cf_standard_name': 'surface_snow_melt_flux', 'cf_cell_methods': 'time: mean'}, 'SOILM': {'cf_standard_name': 'soil_moisture_content', 'cf_cell_methods': None}, 'TSOIL': {'cf_standard_name': 'soil_temperature', 'cf_cell_methods': None}, 'VEG': {'cf_standard_name': 'vegetation_area_fraction', 'cf_cell_methods': None}, 'WATR': {'cf_standard_name': 'runoff_flux', 'cf_cell_methods': 'time: mean'}, 'ALBDO': {'cf_standard_name': 'surface_albedo', 'cf_cell_methods': None}, 'DLWRF': {'cf_standard_name': 'surface_downwelling_longwave_flux_in_air', 'cf_cell_methods': 'time: mean'}, 'DSWRF': {'cf_standard_name': 'surface_downwelling_shortwave_flux_in_air', 'cf_cell_methods': 'time: mean'}, 'GRAD': {'cf_standard_name': 'surface_downwelling_shortwave_flux_in_air', 'cf_cell_methods': 'time: mean'}, 'LHTFL': {'cf_standard_name': 'surface_upward_latent_heat_flux', 'cf_cell_methods': 'time: mean'}, 'NLWRS': {'cf_standard_name': 'surface_net_downward_longwave_flux', 'cf_cell_methods': 'time: mean'}, 'NLWRT': {'cf_standard_name': 'toa_net_downward_longwave_flux', 'cf_cell_methods': 'time: mean'}, 'NSWRS': {'cf_standard_name': 'surface_net_downward_shortwave_flux', 'cf_cell_methods': 'time: mean'}, 'NSWRT': {'cf_standard_name': 'toa_net_downward_shortwave_flux', 'cf_cell_methods': 'time: mean'}, 'SHTFL': {'cf_standard_name': 'surface_upward_sensible_heat_flux', 'cf_cell_methods': 'time: mean'}, 'ULWRF': {'cf_standard_name': 'surface_upwelling_longwave_flux_in_air', 'cf_cell_methods': 'time: mean'}, 'USWRF': {'cf_standard_name': 'surface_upwelling_shortwave_flux_in_air', 'cf_cell_methods': 'time: mean'}, 'DSLM': {'cf_standard_name': 'sea_surface_height_above_sea_level', 'cf_cell_methods': None}, 'HTSGW': {'cf_standard_name': 'sea_surface_wave_significant_height', 'cf_cell_methods': None}, 'ICEC': {'cf_standard_name': 'sea_ice_area_fraction', 'cf_cell_methods': None}, 'ICETK': {'cf_standard_name': 'sea_ice_thickness', 'cf_cell_methods': None}, 'SALTY': {'cf_standard_name': 'sea_water_salinity', 'cf_cell_methods': None}, 'SWELL': {'cf_standard_name': 'sea_surface_swell_wave_significant_height', 'cf_cell_methods': None}, 'SWDIR': {'cf_standard_name': 'sea_surface_swell_wave_from_direction', 'cf_cell_methods': None}, 'SWPER': {'cf_standard_name': 'sea_surface_swell_wave_period', 'cf_cell_methods': None}, 'UOGRD': {'cf_standard_name': 'eastward_sea_water_velocity', 'cf_cell_methods': None}, 'VOGRD': {'cf_standard_name': 'northward_sea_water_velocity', 'cf_cell_methods': None}, 'WVDIR': {'cf_standard_name': 'sea_surface_wind_wave_from_direction', 'cf_cell_methods': None}, 'WVHGT': {'cf_standard_name': 'sea_surface_wind_wave_significant_height', 'cf_cell_methods': None}, 'WVPER': {'cf_standard_name': 'sea_surface_wind_wave_period', 'cf_cell_methods': None}, 'TOZNE': {'cf_standard_name': 'atmosphere_mole_content_of_ozone', 'cf_cell_methods': None}, 'VIS': {'cf_standard_name': 'visibility_in_air', 'cf_cell_methods': None}}
table_4_7_cf = {0: {'cf_cell_methods': 'time: mean'}, 1: {'cf_cell_methods': 'time: mean (comment: weighted)'}, 2: {'cf_cell_methods': 'time: standard_deviation (comment: with respect to cluster mean)'}, 3: {'cf_cell_methods': 'time: standard_deviation (comment: normalized)'}, 4: {'cf_cell_methods': 'time: standard_deviation'}, 5: {'cf_cell_methods': None}, 6: {'cf_cell_methods': 'time: mean (comment: of cluster members)'}, 7: {'cf_cell_methods': 'time: range (comment: interquartile)'}, 8: {'cf_cell_methods': 'time: minimum'}, 9: {'cf_cell_methods': 'time: maximum'}, 10: {'cf_cell_methods': 'time: variance'}, 192: {'cf_cell_methods': 'time: mode'}, 193: {'cf_cell_methods': None}, 194: {'cf_cell_methods': 'time: median'}, 195: {'cf_cell_methods': None}, 197: {'cf_cell_methods': None}, 198: {'cf_cell_methods': None}, 199: {'cf_cell_methods': None}, 200: {'cf_cell_methods': 'time: mean'}, 201: {'cf_cell_methods': None}, 202: {'cf_cell_methods': None}, 203: {'cf_cell_methods': None}, 204: {'cf_cell_methods': None}, 255: {'cf_cell_methods': None}}